@@ -4,11 +4,9 @@ use strict;
 # [10:05:57] <@andyg> Catalyst::View is the correct base class
 use base qw/Catalyst::View/; 
 
-use NEXT;
-
 use Data::Dumper;
 
-our $VERSION = '2.1_03';
+our $VERSION = '2.2_001';
 
 
 =head1 NAME
@@ -237,6 +235,8 @@ sub page2tree {
 sub process {
     my ( $self, $c ) = @_;
 
+    my $body_is_skeleton = 0;
+
     my ($skeleton, $meat, $body) ;
 
     my $loom = $c->stash->{LOOM};
@@ -273,9 +273,7 @@ sub process {
           $self, $c, $c->stash, $meat, $skeleton
        );
 
-      # $body = $self->page2tree($c, $skeleton, 'fixup');
-      # this should be additional controller actions for the request
-
+      $body_is_skeleton = 1;
       $body = $skeleton ;
     }
 
@@ -298,9 +296,9 @@ sub process {
     $c->response->body( $response_body );
 
 
-    # If loom is a class-name we're not doing anything especially fancy, so
-    # we'll just delete it:
-    unless ( ref $loom ) {
+    # we delete the body unless our loom ( or skeleton if we have one) is a reference
+    # which we take as a sign that the user is doing something more elaborate caching or something..
+    unless( (! $body_is_skeleton && ref $loom)  ||  ( $body_is_skeleton && ref $self->config->{skeleton} ) ) {
         $body->delete;
     }
 
@@ -410,11 +408,9 @@ The best way to see a fully working Seamstress-style Perl class is to
 pull down the working sample app from sourceforge.
 
 A working sample app, which does both simple and
-meat-skeleton rendering is available from
-Sourceforge CVS:
+meat-skeleton rendering is available from github:
 
- cvs -d:pserver:anonymous@seamstress.cvs.sourceforge.net:/cvsroot/seamstress login
- cvs -z3 -d:pserver:anonymous@seamstress.cvs.sourceforge.net:/cvsroot/seamstress co -P catalyst-simpleapp
+ git clone   git://github.com/draxil/catalyst--view--seamstress-sample-app.git
 
 =head1 SUPPORT
 
